/*
 * ScheduleTogether Frontend
 * Copyright (C) 2024, Marco Vitchi Thulin
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License version 3 for more details.
 *
 * This program incorporates external libraries for certain functionalities.
 * These libraries are covered by their respective licenses, and their usage
 * agreements are as outlined in their respective documentation or source
 * code.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import { defineStore } from 'pinia';

import { fetchWrapper } from '@/helpers';
import { getApiUrl } from '@/helpers';
import { useAlertStore } from '@/stores'; 

// TODO: Rewrite to TypeScript

const apiUrl = getApiUrl();
const baseUrl = `${apiUrl}/providers`;

export const useProvidersStore = defineStore({
    id: 'providers',
    state: () => ({
        host: {},
        provider: {},
        terms: {},
        schools: [],
        classes: {},
        schedule: {},
    }),
    actions: {
        async setHost(host) {
            // set current target host
            this.host = host;
        },
        async setProvider(provider) {
            // set the chosen provider for the data
            if (!["skola24", "schoolsoft"].includes(provider)) {
                alertStore = useAlertStore();
                alertStore.addAlert('Invalid value for provider');
            } else {
                this.provider = provider;
            }
        },
        async getTerms() {
            const body = {"provider": this.provider, "host": this.host};
            this.terms = { loading: true };
            try {
                // get available terms for target host
                this.terms = JSON.parse(await fetchWrapper.post(`${baseUrl}/terms`, body));
            } catch (error) {
                this.terms = { error };
                const alertStore = useAlertStore(); 
                alertStore.error(error, 10000);
            }
        },
        async getSchools() {
            const body = {"provider": this.provider, "host": this.host};
            this.schools = { loading: true };
            try {
                // get available schools for target host
                this.schools = JSON.parse(await fetchWrapper.post(`${baseUrl}/schools`, body));
            } catch (error) {
                this.schools = { error };
                const alertStore = useAlertStore(); 
                alertStore.error(error, 10000);
            }
        },
        async getClasses(schoolId) {
            const body = {"provider": this.provider, "host": this.host, "school": schoolId};
            this.classes = { loading: true }
            try {
                // get available classes for target host
                this.classes = JSON.parse(await fetchWrapper.post(`${baseUrl}/classes`, body));
                console.log('Classes: ', this.classes);
            } catch (error) {
                this.classes = { error };
                const alertStore = useAlertStore(); 
                alertStore.error(error, 5000);
            }
        },
        async getSchedule(schoolId, classId, termId) {
            const body = {"provider": this.provider, "host": this.host, "school": schoolId, "class": classId, "term": termId};
            this.schedule = { loading: true }
            try {
                // get available classes for target host
                this.schedule = JSON.parse(await fetchWrapper.post(`${baseUrl}/schedule`, body));
            } catch (error) {
                this.schedule = { error };
                const alertStore = useAlertStore(); 
                alertStore.error(error, 5000);
            }
        },
    }
});