/*
 * ScheduleTogether Frontend
 * Copyright (C) 2024, Marco Vitchi Thulin
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License version 3 for more details.
 *
 * This program incorporates external libraries for certain functionalities.
 * These libraries are covered by their respective licenses, and their usage
 * agreements are as outlined in their respective documentation or source
 * code.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import { defineStore } from 'pinia';

import { fetchWrapper } from '@/helpers';
import { getApiUrl } from '@/helpers';
import { useAlertStore } from '@/stores'; 

// TODO: Rewrite to TypeScript

const apiUrl = getApiUrl();
const baseUrl = `${apiUrl}/schedules`;

export const useSchedulesStore = defineStore({
    id: 'schedules',
    state: () => ({
        schedules: {},
        schedule: {},
    }),
    actions: {
        async add(schedule) {
            // add schedule for current user
            await fetchWrapper.post(`${baseUrl}/add`, schedule);
        },
        async getCurrent() {
            this.schedule = { loading: true };
            try {
                // get schedule for current user
                this.schedule = await fetchWrapper.get(`${baseUrl}/current`);
            } catch (error) {
                this.schedule = { error };
                const alertStore = useAlertStore(); 
                alertStore.error(error, 5000);
            }
        },
        async getAll() {
            this.schedules = { loading: true };
            try {
                // get schedules for all users
                this.schedules = await fetchWrapper.get(baseUrl);    
            } catch (error) {
                this.schedules = { error };
                const alertStore = useAlertStore(); 
                alertStore.error(error);
            }
        },
        async getById(id) {
            this.schedule = { loading: true };
            try {
                // get specific schedule by ID
                this.schedule = await fetchWrapper.get(`${baseUrl}/${id}`);
            } catch (error) {
                this.schedule = { error };
                const alertStore = useAlertStore(); 
                alertStore.error(error);
            }
        },
        async update(id, params) {
            this.schedule = { loading: true };
            try {
                // update specific schedule by ID
                await fetchWrapper.put(`${baseUrl}/${id}`, params);
            } catch (error) {
                this.schedule = { error };
                const alertStore = useAlertStore(); 
                alertStore.error(error);
            }
        },
        async delete(id) {
            // add isDeleting prop to schedule being deleted
            this.schedules.find(x => x.id === id).isDeleting = true;

            // delete schedule
            await fetchWrapper.delete(`${baseUrl}/${id}`);

            // remove schedule from list after deleted
            this.schedules = this.schedules.filter(x => x.id !== id);
        },
        async deleteCurrent() {
            // add isDeleting prop to schedule being deleted
            this.schedule.isDeleting = true;

            // delete schedule
            await fetchWrapper.delete(`${baseUrl}/current`);

            // remove schedule
            this.schedule = {};
        }
    }
});